@@ -6,16 +6,6 @@ class _SDCG(measures.Measure):
     """
     The Scaled Discounted Cumulative Gain (SDCG), a variant of nDCG that assumes more
     fully-relevant documents exist but are not labeled.
-
-::
-
-     @inproceedings{Moffat:2015:IAM:2838931.2838938,
-       author = {Moffat, Alistair and Bailey, Peter and Scholer, Falk and Thomas, Paul},
-       title = {INST: An Adaptive Metric for Information Retrieval Evaluation},
-       booktitle = {Proceedings of the 20th Australasian Document Computing Symposium},
-       year = {2015},
-       url = {http://doi.acm.org/10.1145/2838931.2838938}
-     }
     """
     __name__ = 'SDCG'
     NAME = __name__
