@@ -5,7 +5,9 @@ def register(provider):
 
 from .base import Provider, Evaluator
 from .fallback_provider import FallbackProvider
+from .compat_provider import CompatProvider
 from .cwl_eval import CwlEvalProvider, CwlMetric
+from .pyndeval_provider import PyNdEvalProvider
 from .pytrec_eval_provider import PytrecEvalProvider
 from .judged_provider import JudgedProvider
 from .gdeval_provider import GdevalProvider
